@@ -1,7 +1,7 @@
 #!/usr/bin/perl
 #[[BEGIN PROPERTIES]]
 # Type = Command
-# Order = 5.0
+# Order = 7.0
 # Interpreter = perl
 # Caption = Move
 # Descr =Move one or more files and/or directories into another
@@ -13,8 +13,7 @@
 # Descr =
 # Descr =  Target: The target directory, or a single target file
 # Descr =          to be overwritten by a single source file.
-# ButtonBgColor = #BB5
-# ButtonFgColor = #000
+# Icon = move_file.tga
 # Hotkey = Ctrl+M
 #[[END PROPERTIES]]
 
@@ -28,7 +27,7 @@ if (IsFirstPass()) {
 	ErrorIfNotSingleTarget();
 	ErrorIfRootSources();
 
-	ConfirmIfSourcesAccrossDirs();
+	ConfirmIfSourcesAcrossDirs();
 
 	my $message=
 		"Are you sure to move, overwriting any existing target files?\n".
