@@ -1,7 +1,7 @@
 //------------------------------------------------------------------------------
 // emPanel.h
 //
-// Copyright (C) 2004-2008,2010 Oliver Hamann.
+// Copyright (C) 2004-2008,2010-2012,2014-2017 Oliver Hamann.
 //
 // Homepage: http://eaglemode.sourceforge.net/
 //
@@ -86,7 +86,7 @@ public:
 		emView & GetView() const;
 		emPanel * GetPanel() const;
 	private:
-		emView & View;
+		emView * View;
 		emPanel * Panel;
 	};
 
@@ -102,7 +102,7 @@ public:
 		//            panel or a view. If it is a view, this panel will
 		//            be the root panel of that view. Otherwise it will
 		//            be the last child of the parent panel. Note that
-		//            the type ParentArg can be casted implicitly from:
+		//            the type ParentArg can be cast implicitly from:
 		//            emPanel&, emPanel*, emView& and emView*. But the
 		//            pointer must never be NULL.
 		//   name   - The name for this panel. There must not be any
@@ -125,50 +125,51 @@ public:
 		// They are delimited by colons, while colons and backslashes in
 		// the names are quoted by backslashes.
 
-	emUInt64 GetCreationNumber() const;
-		// This is a generic consecutive identification number for this
-		// panel. It is unique within the view. Whenever a panel is
-		// created, a private counter in the view is incremented by one,
-		// and the panel gets that number as its creation number.
-
-	virtual emString GetTitle();
+	virtual emString GetTitle() const;
 		// Get the title of this panel. Normally, the title of the
 		// active panel is shown as the title of the view. The default
 		// implementation of this method asks the parent panel. See
 		// also: InvalidateTitle()
 
-	emView & GetView();
+	virtual emString GetIconFileName() const;
+		// Get the file name of an icon for this panel. For example,
+		// this is used in bookmarks. The returned string can be the
+		// name of a file in the default icon directory, or an absolute
+		// file path. An empty string means to have no icon. The default
+		// implementation of this method asks the parent panel.
+
+	emView & GetView() const;
 		// Get the view.
 
-	emContext & GetViewContext();
+	emContext & GetViewContext() const;
 		// Get the context of the view, this is just like GetView()
 		// because emView is an emContext. (Yes, this method is
 		// unnecessary)
 
-	emRootContext & GetRootContext();
+	emRootContext & GetRootContext() const;
 		// Get the root context (don't confuse with root panel).
 
-	emWindow * GetWindow();
-	emScreen * GetScreen();
+	emWindow * GetWindow() const;
+	emScreen * GetScreen() const;
 		// These are short cuts for GetView().GetWindow() and
 		// GetView().GetScreen().
 
-	emPanel * GetParent();
+	emPanel * GetParent() const;
 		// Get the parent panel. Returns NULL if this is the root panel.
 
-	emPanel * GetChild(const char * name);
+	emPanel * GetChild(const char * name) const;
 		// Search a child panel by name. Returns NULL if there is no
 		// such panel.
 
-	emPanel * GetFirstChild();
-	emPanel * GetLastChild();
+	emPanel * GetFirstChild() const;
+	emPanel * GetLastChild() const;
 		// Get the first or last child panel. The first child panel is
 		// painted at first, and the last one is painted at last (first
 		// means bottom, last means top). Returns NULL if this panel has
 		// no children.
 
-	emPanel * GetPrev();
-	emPanel * GetNext();
+	emPanel * GetPrev() const;
+	emPanel * GetNext() const;
 		// Get the previous or next panel within the list of the
 		// parent's list of children. It is painted before or after this
 		// panel, respectively. Returns NULL if this is the first or
@@ -245,21 +246,39 @@ public:
 		// height/width ratios instead of width/height ratios. Let's
 		// call it "tallness".
 
+	virtual void GetSubstanceRect(double * pX, double * pY,
+	                              double * pW, double * pH,
+	                              double * pR) const;
+		// Get the substance rectangle of this panel. This should
+		// surround everything except empty margins and shadows. It is
+		// used by emView to paint the focus rectangle, and it is used
+		// to filter mouse and touch events (the panel will not get such
+		// events outside of the rectangle). The returned rectangle is
+		// in the coordinate system of this panel. It can have round
+		// corners (*pR is set to the radius). The default
+		// implementation returns the whole panel rectangle with zero
+		// radius.
+
+	bool IsPointInSubstanceRect(double x, double y) const;
+		// Ask if a point lies within the substance rectangle. The point
+		// must be given in the coordinate system of this panel.
+
 	virtual void GetEssenceRect(double * pX, double * pY,
-	                            double * pW, double * pH);
+	                            double * pW, double * pH) const;
 		// Get the essence rectangle of this panel. When the panel is to
 		// be shown full-sized in the view, this rectangular part of the
 		// panel is actually shown full-sized. The returned rectangle is
 		// in the coordinate system of this panel. The default
-		// implementation returns the whole panel rectangle.
+		// implementation calls GetSubstanceRect(...).
 
 	bool IsViewed() const;
 	bool IsInViewedPath() const;
 		// A panel is viewed if it is painted to the view. And a panel
 		// is in viewed path if itself or a descendant is viewed. There
 		// is always exactly one viewed panel within the whole tree of
-		// panels, whose parent is not viewed. It is called the supreme
-		// viewed panel. Thus, the viewed panels are making up a tree.
+		// panels, whose parent is not viewed (or which does not have a
+		// parent). It is called the supreme viewed panel. The viewed
+		// panels are making up a tree.
 
 	double GetViewedPixelTallness() const;
 		// Same as GetView().GetCurrentPixelTallness()
@@ -345,6 +364,10 @@ public:
 		// (see AutoExpand()). The default should be okay for normal
 		// cases.
 
+	bool IsAutoExpanded() const;
+		// Whether this panel is currently auto-expanded (see
+		// AutoExpand()).
+
 	virtual void SetEnableSwitch(bool enableSwitch);
 	bool GetEnableSwitch() const;
 	bool IsEnabled() const;
@@ -363,11 +386,11 @@ public:
 		// root panel must always be focusable. Thus, it has no effect
 		// to call SetFocusable(false) on the root panel.
 
-	emPanel * GetFocusableParent();
-	emPanel * GetFocusableFirstChild();
-	emPanel * GetFocusableLastChild();
-	emPanel * GetFocusablePrev();
-	emPanel * GetFocusableNext();
+	emPanel * GetFocusableParent() const;
+	emPanel * GetFocusableFirstChild() const;
+	emPanel * GetFocusableLastChild() const;
+	emPanel * GetFocusablePrev() const;
+	emPanel * GetFocusableNext() const;
 		// Like GetParent, GetFirstChild and so on, but these methods
 		// behave like if all non-focusable panels would have been
 		// removed from the panel tree. At such a thought removal, the
@@ -376,15 +399,6 @@ public:
 		// non-focusable panels. They are just additional possible start
 		// points for the search.
 
-	bool IsVisited() const;
-	bool IsInVisitedPath() const;
-		// There is always exactly one viewed panel which is called the
-		// visited panel. It is the anchor for the view within the panel
-		// tree. That means, if the layout of any panel is modified, the
-		// visited panel keeps its position and size within the view. A
-		// panel is in visited path if itself or any descendant is
-		// visited.
-
 	bool IsActive() const;
 	bool IsInActivePath() const;
 		// There is always exactly one panel, which is called the active
@@ -394,29 +408,16 @@ public:
 		// focused panel (see IsFocused()). A panel cannot be active if
 		// it is not focusable (see SetFocusable()). A panel is in
 		// active path if itself or any descendant is the active panel.
-		//
-		// Why is there a difference between visited and active? Indeed,
-		// normally the active panel is even the visited panel. But the
-		// visited panel must be a viewed panel, and the active panel
-		// must be focusable. On the other hand, the supreme viewed
-		// panel is chosen for optimum performance and for avoiding
-		// over/under-flows of floating point numbers. So there can be
-		// one special case where the visited panel and the active panel
-		// are not the same: The visited panel is the supreme viewed
-		// panel, and it is not focusable, and the active panel is the
-		// nearest focusable ancestor of the visited panel.
 
-	void Activate();
+	bool IsActivatedAdherent() const;
+		// Ask whether this panel is activated adherent. "Adherent"
+		// usually means that the activation has been made by the user.
+		// An adherent activation is not so easy to change by zooming
+		// and scrolling like a non-adherent activation.
+
+	void Activate(bool adherent=true);
 		// Make this the active panel, or if this panel is not
-		// focusable, make the nearest focusable ancestor active. This
-		// method is a short cut for: GetView().VisitLazy(this,true)
-
-	void ActivateLater();
-		// Mark this panel for being activated at the end of the current
-		// time slice. This gives time for other things to come first,
-		// especially layout updates which may unhide this panel. If
-		// this is called on multiple panels of the same view within the
-		// same time slice, the last call counts.
+		// focusable, make the nearest focusable ancestor active.
 
 	bool IsFocused() const;
 	bool IsInFocusedPath() const;
@@ -428,7 +429,7 @@ public:
 	bool IsViewFocused() const;
 		// Ask whether the view has the input focus.
 
-	void Focus();
+	void Focus(bool adherent=true);
 		// Make this the focused panel, or if this panel is not
 		// focusable, make the nearest focusable ancestor focused. This
 		// is like calling Activate() and GetView().Focus().
@@ -449,6 +450,88 @@ public:
 		// can have any size, and we have to make sure that the overall
 		// process does not consume too much memory.
 
+	emUInt64 GetInputClockMS() const;
+		// Get the time of the currently handled input event and input
+		// state, or the current time if all events are handled. The
+		// time is measured in milliseconds and starts anywhere, but it
+		// should never overflow.
+
+	virtual double GetTouchEventPriority(double touchX, double touchY) const;
+		// Get the priority of this panel for receiving touch events.
+		// This is used by certain view input filters to decide whether
+		// to eat touch events for their purpose. Remember the
+		// possibility of an emSubViewPanel. Currently, following
+		// priorities are defined:
+		//  0.0 - No touch event processing.
+		//  1.0 - Set focus by touches.
+		//  2.0 - Emulate mouse functions by touches.
+		//  3.0 - Emulate mouse functions, and zoom/scroll by touches.
+		// The default implementation returns 0.0 when not focusable, or
+		// 1.0 when focusable, according to the default implementation
+		// of the Input method.
+		// Arguments:
+		//   touchX, touchY - Position of a first touch in view
+		//                    coordinates.
+
+	typedef int AutoplayHandlingFlags;
+	enum {
+		APH_ITEM               = (1<<0),
+		APH_DIRECTORY          = (1<<1),
+		APH_CUTOFF             = (1<<2),
+		APH_CUTOFF_AT_SUBITEMS = (1<<3)
+	};
+	virtual void SetAutoplayHandling(AutoplayHandlingFlags flags);
+	AutoplayHandlingFlags GetAutoplayHandling() const;
+		// How this panel shall be handled by an autoplay function:
+		//  APH_ITEM               - This panel is worth to be shown or
+		//                           played by autoplay. This flag is set
+		//                           by default, but it is ignored if
+		//                           the panel is not focusable.
+		//  APH_DIRECTORY          - Autoplay shall enter or leave this
+		//                           sub-tree only when acting recursively.
+		//                           This flag is ignored if the panel is
+		//                           not focusable.
+		//  APH_CUTOFF             - Autoplay shall never enter or leave
+		//                           this sub-tree. If APH_ITEM is also
+		//                           set, the panel may be shown as part
+		//                           of the upper tree.
+		//  APH_CUTOFF_AT_SUBITEMS - Force any sub-items to act like
+		//                           APH_CUTOFF.
+
+	virtual bool IsContentReady(bool * pReadying=NULL) const;
+		// Ask if this panel has created all its child panels and if it
+		// is ready for showing or playback. If not, *pReadying is set
+		// to whether the panel will be ready later. Otherwise the panel
+		// may not be ready because it is not viewed completely or large
+		// enough. This method may be polled by autoplay. It should only
+		// be called through a low-priority engine. The default
+		// implementation returns IsAutoExpanded() and readying false.
+
+	virtual bool GetPlaybackState(bool * pPlaying, double * pPos=NULL) const;
+		// Get the playback state of this panel.
+		// Arguments:
+		//   pPlaying - Pointer for returning whether playpack is active.
+		//   pPos     - Optional pointer for returning the playback
+		//              position in the range of 0.0 to 1.0.
+		//              If *pPlaying is set to false, *pPos==0.0 means
+		//              stopped by user or never started, and *Pos==1.0
+		//              means stopped by playing to the end, and
+		//              0.0<*pPos<1.0 means paused by user at that
+		//              position.
+		// Returns:
+		//   Whether this panel supports playback. The default
+		//   implementation returns false.
+
+	virtual bool SetPlaybackState(bool playing, double pos=-1.0);
+		// Set the playback state of this panel.
+		// Arguments:
+		//   playing - Whether playpack shall be active or not.
+		//   pos     - Desired playback position in the range of 0.0 to
+		//             1.0. -1.0 means not to change the position.
+		// Returns:
+		//   Whether this panel supports playback. The default
+		//   implementation returns false.
+
 protected:
 
 	virtual bool Cycle();
@@ -457,17 +540,16 @@ protected:
 
 	typedef emUInt16 NoticeFlags;
 	enum {
-		NF_CHILD_LIST_CHANGED       = (1<< 0),
-		NF_LAYOUT_CHANGED           = (1<< 1),
-		NF_VIEWING_CHANGED          = (1<< 2),
-		NF_ENABLE_CHANGED           = (1<< 3),
-		NF_VISIT_CHANGED            = (1<< 4),
-		NF_ACTIVE_CHANGED           = (1<< 5),
-		NF_FOCUS_CHANGED            = (1<< 6),
-		NF_VIEW_FOCUS_CHANGED       = (1<< 7),
-		NF_UPDATE_PRIORITY_CHANGED  = (1<< 8),
-		NF_MEMORY_LIMIT_CHANGED     = (1<< 9),
-		NF_SOUGHT_NAME_CHANGED      = (1<<10)
+		NF_CHILD_LIST_CHANGED       = (1<<0),
+		NF_LAYOUT_CHANGED           = (1<<1),
+		NF_VIEWING_CHANGED          = (1<<2),
+		NF_ENABLE_CHANGED           = (1<<3),
+		NF_ACTIVE_CHANGED           = (1<<4),
+		NF_FOCUS_CHANGED            = (1<<5),
+		NF_VIEW_FOCUS_CHANGED       = (1<<6),
+		NF_UPDATE_PRIORITY_CHANGED  = (1<<7),
+		NF_MEMORY_LIMIT_CHANGED     = (1<<8),
+		NF_SOUGHT_NAME_CHANGED      = (1<<9)
 	};
 	virtual void Notice(NoticeFlags flags);
 		// Called some time after this panel has possibly changed in
@@ -480,7 +562,6 @@ protected:
 		//                                GetViewed...(), GetClip...(),
 		//                                GetViewCondition(...)
 		//   NF_ENABLE_CHANGED          - IsEnabled()
-		//   NF_VISIT_CHANGED           - IsVisited(), IsInVisitedPath()
 		//   NF_ACTIVE_CHANGED          - IsActive(), IsInActivePath()
 		//   NF_FOCUS_CHANGED           - IsFocused(), IsInFocusedPath()
 		//   NF_VIEW_FOCUS_CHANGED      - IsViewFocused()
@@ -491,26 +572,36 @@ protected:
 
 	virtual void Input(emInputEvent & event, const emInputState & state,
 	                   double mx, double my);
-		// Process input form keyboard and mouse. This method is called
-		// on every panel which has IsInViewedPath()==true whenever
-		// there is a change in the input state or when there is an
-		// input event. The order of callings is from children to
-		// parents and from top to bottom (=last to first). The default
-		// implementation does this: First, if it is a mouse event and
-		// if this panel is focusable, the focus is set to this panel
-		// and the mouse event is eaten. And secondly, if this is the
-		// active panel, certain keyboard events are processed and eaten
-		// for switching the focus to another panel.
+		// Process input form keyboard, mouse, and touch. This method is
+		// called on every panel whenever there is a change in the input
+		// state or when there is an input event. The order of callings
+		// is from children to parents and from top to bottom (=last to
+		// first). The default implementation does this: First, if it is
+		// a mouse or touch event and if this panel is focusable, the
+		// focus is set to this panel and the event is eaten. And
+		// secondly, if this is the active panel, certain keyboard
+		// events are processed and eaten for switching the focus to
+		// another panel. Also see the methods GetInputClockMS and
+		// GetTouchEventPriority.
 		// Arguments:
 		//   event  - An input event. This is non-empty only if:
 		//            * It is a mouse button event, and the mouse
-		//              position lies within the panel and all its
-		//              ancestors, and the event has not been eaten by a
-		//              descendant panel or by an overlapping panel in
-		//              front.
+		//              position lies within the substance rectangles of
+		//              the panel and of all of its ancestors, and the
+		//              event has not been eaten by a descendant panel
+		//              or by an overlapping panel in front or by a view
+		//              input filter.
+		//            * It is a touch event, and the first touch
+		//              position lies within the substance rectangles of
+		//              the panel and of all of its ancestors, and the
+		//              event has not been eaten by a descendant panel
+		//              or by an overlapping panel in front or by a view
+		//              input filter. Normally, touch events are
+		//              converted to mouse events by a view input
+		//              filter.
 		//            * It is a keyboard key event, and this panel is in
 		//              focused path, and the event has not been eaten
-		//              by a descendant panel.
+		//              by a descendant panel or by a view input filter.
 		//            The event can be eaten by calling event.Eat(). The
 		//            event reference is non-const only for that. Please
 		//            do not modify the event in any other way.
@@ -518,25 +609,39 @@ protected:
 		//            state.GetMouseX/Y are from the coordinate system
 		//            of the view (thus, they are in pixels).
 		//   mx, my - Position of the mouse in the coordinate system of
-		//            this panel.
+		//            this panel. Valid only if IsInViewedPath().
 
-	virtual emCursor GetCursor();
+	virtual emCursor GetCursor() const;
 		// Get the mouse cursor to be shown for this panel. The default
 		// implementation asks the parent panel. See also:
 		// InvalidateCursor()
 
-	virtual bool IsOpaque();
+	virtual bool IsOpaque() const;
 		// Whether this panel is completely opaque by its painting or by
 		// its child panels. If true, the background may not be
 		// initialized when the panel is painted. It even helps the view
 		// to choose a better supreme viewed panel. The default
 		// implementation returns false. See also: InvalidatePainting()
 
-	virtual void Paint(const emPainter & painter, emColor canvasColor);
+	virtual void Paint(const emPainter & painter, emColor canvasColor) const;
 		// Paint this panel. The default implementation does nothing.
 		// Note that for a single painting of the whole panel, this
 		// method may be called multiple times with different clipping
 		// rectangles in order to optimize cache usage.
+		//
+		// ***************** CAUTION: MULTI-THREADING ******************
+		// * In order to improve the graphics performance on           *
+		// * multi-core CPUs, Paint may be called by multiple threads  *
+		// * in parallel, but in a way that there is always at most    *
+		// * one thread at a time in user code, outside any call to    *
+		// * emPainter. There is a shared mutex which is entered       *
+		// * before a thread calls an emPanel::Paint. It is left only  *
+		// * while the thread is in a call to a method of emPainter    *
+		// * and re-entered before such a call returns.                *
+		// * Please prepare your code for this. Ideally, do not modify *
+		// * any shared data in an implementation of Paint.            *
+		// *************************************************************
+		//
 		// Arguments:
 		//   painter     - A painter for painting the panel to the
 		//                 screen. Origin and scaling of this painter
@@ -549,11 +654,6 @@ protected:
 		//                 color.
 		// See also: InvalidatePainting()
 
-	void EnableAutoExpansion();
-		// Enable the auto-expansion mechanism. This must be called in
-		// the constructors of panel classes which overload the method
-		// AutoExpand().
-
 	virtual void AutoExpand();
 		// Create child panels by auto-expansion. Often it is a good
 		// idea to dynamically create and delete the children of a panel
@@ -564,7 +664,7 @@ protected:
 		// does nothing. AutoExpand is called when the view condition
 		// reaches a threshold value. As soon as the view condition
 		// falls below again, the child panels are deleted through
-		// calling AutoShrink(). See also: EnableAutoExpansion(),
+		// calling AutoShrink(). See also:
 		// SetAutoExpansionThreshold(...), AutoShrink(),
 		// InvalidateAutoExpansion().
 
@@ -609,7 +709,7 @@ protected:
 		// method returns the name of the sought child panel. Otherwise
 		// it returns NULL.
 
-	virtual bool IsHopeForSeeking();
+	virtual bool IsHopeForSeeking() const;
 		// While the view is seeking for a still non-existent child of
 		// this panel, this method is called by the view on every time
 		// slice for asking whether there is any hope that the desired
@@ -657,6 +757,29 @@ protected:
 		// After calling this, the control panel will be re-created, but
 		// only if it is shown.
 
+	// - - - - - - - - - - Depreciated methods - - - - - - - - - - - - - - -
+	// The following virtual non-const methods have been replaced by const
+	// methods (see above). The old versions still exist here with the
+	// "final" keyword added, so that old overridings will fail to compile.
+	// If you run into this, please adapt your overridings by adding
+	// "const". Besides, please read the new comments about multi-threading
+	// in Paint more above.
+public:
+	virtual emString GetTitle() final;
+	virtual emString GetIconFileName() final;
+	virtual void GetSubstanceRect(double * pX, double * pY,
+	                              double * pW, double * pH,
+	                              double * pR) final;
+	virtual void GetEssenceRect(double * pX, double * pY,
+	                            double * pW, double * pH) final;
+	virtual double GetTouchEventPriority(double touchX, double touchY) final;
+protected:
+	virtual emCursor GetCursor() final;
+	virtual bool IsOpaque() final;
+	virtual void Paint(const emPainter & painter, emColor canvasColor) final;
+	virtual bool IsHopeForSeeking() final;
+	// - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
+
 private:
 
 	friend class emView;
@@ -683,7 +806,6 @@ private:
 	double ViewedX, ViewedY, ViewedWidth, ViewedHeight;
 	double ClipX1, ClipY1, ClipX2, ClipY2;
 	double AEThresholdValue;
-	emUInt64 CreationNumber;
 	emColor CanvasColor;
 	NoticeFlags PendingNoticeFlags;
 	unsigned Viewed : 1;
@@ -691,48 +813,47 @@ private:
 	unsigned EnableSwitch : 1;
 	unsigned Enabled : 1;
 	unsigned Focusable : 1;
-	unsigned Visited : 1;
-	unsigned InVisitedPath : 1;
 	unsigned Active : 1;
 	unsigned InActivePath : 1;
 	unsigned PendingInput : 1;
 	unsigned ChildrenLayoutInvalid : 1;
-	unsigned AEEnabled : 1;
+	unsigned AEInvalid : 1;
 	unsigned AEDecisionInvalid : 1;
 	unsigned AECalling : 1;
 	unsigned AEExpanded : 1;
 	unsigned CreatedByAE : 1;
 	unsigned AEThresholdType : 3;
+	unsigned AutoplayHandling : 4;
 };
 
 inline emPanel::ParentArgClass::ParentArgClass(emPanel & panel)
-	: View(panel.View),Panel(&panel)
+	: View(&panel.View),Panel(&panel)
 {
 }
 
 inline emPanel::ParentArgClass::ParentArgClass(emPanel * panel)
-	: View(panel->View),Panel(panel)
+	: View(&panel->View),Panel(panel)
 {
 }
 
 inline emPanel::ParentArgClass::ParentArgClass(emView & view)
-	: View(view),Panel(NULL)
+	: View(&view),Panel(NULL)
 {
 }
 
 inline emPanel::ParentArgClass::ParentArgClass(emView * view)
-	: View(*view),Panel(NULL)
+	: View(view),Panel(NULL)
 {
 }
 
 inline emRootContext & emPanel::ParentArgClass::GetRootContext() const
 {
-	return View.GetRootContext();
+	return View->GetRootContext();
 }
 
 inline emView & emPanel::ParentArgClass::GetView() const
 {
-	return View;
+	return *View;
 }
 
 inline emPanel * emPanel::ParentArgClass::GetPanel() const
@@ -750,57 +871,52 @@ inline const emString & emPanel::GetName() const
 	return Name;
 }
 
-inline emUInt64 emPanel::GetCreationNumber() const
-{
-	return CreationNumber;
-}
-
-inline emView & emPanel::GetView()
+inline emView & emPanel::GetView() const
 {
 	return View;
 }
 
-inline emContext & emPanel::GetViewContext()
+inline emContext & emPanel::GetViewContext() const
 {
 	return View;
 }
 
-inline emRootContext & emPanel::GetRootContext()
+inline emRootContext & emPanel::GetRootContext() const
 {
 	return View.GetRootContext();
 }
 
-inline emWindow * emPanel::GetWindow()
+inline emWindow * emPanel::GetWindow() const
 {
 	return View.GetWindow();
 }
 
-inline emScreen * emPanel::GetScreen()
+inline emScreen * emPanel::GetScreen() const
 {
 	return View.GetScreen();
 }
 
-inline emPanel * emPanel::GetParent()
+inline emPanel * emPanel::GetParent() const
 {
 	return Parent;
 }
 
-inline emPanel * emPanel::GetFirstChild()
+inline emPanel * emPanel::GetFirstChild() const
 {
 	return FirstChild;
 }
 
-inline emPanel * emPanel::GetLastChild()
+inline emPanel * emPanel::GetLastChild() const
 {
 	return LastChild;
 }
 
-inline emPanel * emPanel::GetPrev()
+inline emPanel * emPanel::GetPrev() const
 {
 	return Prev;
 }
 
-inline emPanel * emPanel::GetNext()
+inline emPanel * emPanel::GetNext() const
 {
 	return Next;
 }
@@ -950,6 +1066,11 @@ inline emPanel::ViewConditionType emPanel::GetAutoExpansionThresholdType() const
 	return (ViewConditionType)AEThresholdType;
 }
 
+inline bool emPanel::IsAutoExpanded() const
+{
+	return AEExpanded;
+}
+
 inline bool emPanel::GetEnableSwitch() const
 {
 	return EnableSwitch;
@@ -965,16 +1086,6 @@ inline bool emPanel::IsFocusable() const
 	return Focusable;
 }
 
-inline bool emPanel::IsVisited() const
-{
-	return Visited;
-}
-
-inline bool emPanel::IsInVisitedPath() const
-{
-	return InVisitedPath;
-}
-
 inline bool emPanel::IsActive() const
 {
 	return Active;
@@ -985,6 +1096,11 @@ inline bool emPanel::IsInActivePath() const
 	return InActivePath;
 }
 
+inline bool emPanel::IsActivatedAdherent() const
+{
+	return Active && View.IsActivationAdherent();
+}
+
 inline bool emPanel::IsFocused() const
 {
 	return Active && View.IsFocused();
@@ -1000,6 +1116,16 @@ inline bool emPanel::IsViewFocused() const
 	return View.IsFocused();
 }
 
+inline emUInt64 emPanel::GetInputClockMS() const
+{
+	return View.GetInputClockMS();
+}
+
+inline emPanel::AutoplayHandlingFlags emPanel::GetAutoplayHandling() const
+{
+	return AutoplayHandling;
+}
+
 inline void emPanel::InvalidateChildrenLayout()
 {
 	ChildrenLayoutInvalid=1;
