@@ -1,7 +1,7 @@
 //------------------------------------------------------------------------------
 // emRec.h - Recordable data structures
 //
-// Copyright (C) 2005-2010 Oliver Hamann.
+// Copyright (C) 2005-2010,2012,2014,2016,2018 Oliver Hamann.
 //
 // Homepage: http://eaglemode.sourceforge.net/
 //
@@ -151,20 +151,20 @@ public:
 		// the beginning of the file. The default implementation returns
 		// NULL which means to have no file format magic.
 
-	void TryLoad(const emString & filePath) throw(emString);
-	void TrySave(const emString & filePath) throw(emString);
+	void TryLoad(const emString & filePath);
+	void TrySave(const emString & filePath);
 		// Load or save this tree of records from or to a file.
 		// Arguments:
 		//   filePath - Path/name of the file.
 
-	void TryLoadFromMem(const char * buf, int len) throw(emString);
-	void TryLoadFromMem(const emArray<char> & buf) throw(emString);
+	void TryLoadFromMem(const char * buf, int len);
+	void TryLoadFromMem(const emArray<char> & buf);
 	void SaveToMem(emArray<char> & buf);
 		// Load or save this tree of records from or to memory.
 		// SaveToMem adds the data to the array without emptying it
 		// first.
 
-	void TryCopy(emRec & source) throw(emString);
+	void TryCopy(emRec & source);
 	void Copy(emRec & source);
 		// Copy the given tree of records to this tree of records via
 		// the SaveToMem and TryLoadFromMem methods. This is slow and
@@ -180,11 +180,11 @@ public:
 		// writing an emStructRec, members with default state may be
 		// omitted.
 
-	virtual void TryStartReading(emRecReader & reader) throw(emString) = 0;
-	virtual bool TryContinueReading(emRecReader & reader) throw(emString) = 0;
+	virtual void TryStartReading(emRecReader & reader) = 0;
+	virtual bool TryContinueReading(emRecReader & reader) = 0;
 	virtual void QuitReading() = 0;
-	virtual void TryStartWriting(emRecWriter & writer) throw(emString) = 0;
-	virtual bool TryContinueWriting(emRecWriter & writer) throw(emString) = 0;
+	virtual void TryStartWriting(emRecWriter & writer) = 0;
+	virtual bool TryContinueWriting(emRecWriter & writer) = 0;
 	virtual void QuitWriting() = 0;
 		// This is only to be called by emRecReader/Writer and through
 		// recursion in the tree. Try to read or write this tree of
@@ -337,11 +337,11 @@ public:
 
 	virtual void SetToDefault();
 	virtual bool IsSetToDefault() const;
-	virtual void TryStartReading(emRecReader & reader) throw(emString);
-	virtual bool TryContinueReading(emRecReader & reader) throw(emString);
+	virtual void TryStartReading(emRecReader & reader);
+	virtual bool TryContinueReading(emRecReader & reader);
 	virtual void QuitReading();
-	virtual void TryStartWriting(emRecWriter & writer) throw(emString);
-	virtual bool TryContinueWriting(emRecWriter & writer) throw(emString);
+	virtual void TryStartWriting(emRecWriter & writer);
+	virtual bool TryContinueWriting(emRecWriter & writer);
 	virtual void QuitWriting();
 	virtual emUInt64 CalcRecMemNeed() const;
 		// See emRec.
@@ -407,11 +407,11 @@ public:
 
 	virtual void SetToDefault();
 	virtual bool IsSetToDefault() const;
-	virtual void TryStartReading(emRecReader & reader) throw(emString);
-	virtual bool TryContinueReading(emRecReader & reader) throw(emString);
+	virtual void TryStartReading(emRecReader & reader);
+	virtual bool TryContinueReading(emRecReader & reader);
 	virtual void QuitReading();
-	virtual void TryStartWriting(emRecWriter & writer) throw(emString);
-	virtual bool TryContinueWriting(emRecWriter & writer) throw(emString);
+	virtual void TryStartWriting(emRecWriter & writer);
+	virtual bool TryContinueWriting(emRecWriter & writer);
 	virtual void QuitWriting();
 	virtual emUInt64 CalcRecMemNeed() const;
 		// See emRec.
@@ -472,6 +472,9 @@ public:
 		//   minValue      - The value will never be less than this.
 		//   maxValue      - The value will never be greater than this.
 
+	virtual ~emDoubleRec();
+		// Destructor.
+
 	double Get() const;
 	operator double () const;
 		// Get the value.
@@ -487,11 +490,11 @@ public:
 
 	virtual void SetToDefault();
 	virtual bool IsSetToDefault() const;
-	virtual void TryStartReading(emRecReader & reader) throw(emString);
-	virtual bool TryContinueReading(emRecReader & reader) throw(emString);
+	virtual void TryStartReading(emRecReader & reader);
+	virtual bool TryContinueReading(emRecReader & reader);
 	virtual void QuitReading();
-	virtual void TryStartWriting(emRecWriter & writer) throw(emString);
-	virtual bool TryContinueWriting(emRecWriter & writer) throw(emString);
+	virtual void TryStartWriting(emRecWriter & writer);
+	virtual bool TryContinueWriting(emRecWriter & writer);
 	virtual void QuitWriting();
 	virtual emUInt64 CalcRecMemNeed() const;
 		// See emRec.
@@ -570,24 +573,24 @@ public:
 	const char * GetIdentifier() const;
 		// Get the identifier for the current value.
 
-	int GetIdentifierCount();
+	int GetIdentifierCount() const;
 		// Get number of possible values.
 
-	const char * GetIdentifierOf(int value);
+	const char * GetIdentifierOf(int value) const;
 		// Get the identifier for the given value. Returns NULL if the
 		// value is out of range.
 
-	int GetValueOf(const char * identifier);
+	int GetValueOf(const char * identifier) const;
 		// Get the value for the given identifier. Returns -1 if there
 		// is no such identifier.
 
 	virtual void SetToDefault();
 	virtual bool IsSetToDefault() const;
-	virtual void TryStartReading(emRecReader & reader) throw(emString);
-	virtual bool TryContinueReading(emRecReader & reader) throw(emString);
+	virtual void TryStartReading(emRecReader & reader);
+	virtual bool TryContinueReading(emRecReader & reader);
 	virtual void QuitReading();
-	virtual void TryStartWriting(emRecWriter & writer) throw(emString);
-	virtual bool TryContinueWriting(emRecWriter & writer) throw(emString);
+	virtual void TryStartWriting(emRecWriter & writer);
+	virtual bool TryContinueWriting(emRecWriter & writer);
 	virtual void QuitWriting();
 	virtual emUInt64 CalcRecMemNeed() const;
 		// See emRec.
@@ -621,7 +624,7 @@ inline const char * emEnumRec::GetIdentifier() const
 	return Identifiers[Value];
 }
 
-inline int emEnumRec::GetIdentifierCount()
+inline int emEnumRec::GetIdentifierCount() const
 {
 	return IdentifierCount;
 }
@@ -667,24 +670,24 @@ public:
 	emFlagsRec & operator = (int value);
 		// Set the value. Undefined flag bits are set to zero.
 
-	int GetIdentifierCount();
+	int GetIdentifierCount() const;
 		// Get number of possible flag bits.
 
-	const char * GetIdentifierOf(int bit);
+	const char * GetIdentifierOf(int bit) const;
 		// Get the identifier for the given flag bit (0...31). Returns
 		// NULL when no identifier has been defined for the bit.
 
-	int GetBitOf(const char * identifier);
+	int GetBitOf(const char * identifier) const;
 		// Get the flag bit for the given identifier. Returns -1 if
 		// there is no such identifier.
 
 	virtual void SetToDefault();
 	virtual bool IsSetToDefault() const;
-	virtual void TryStartReading(emRecReader & reader) throw(emString);
-	virtual bool TryContinueReading(emRecReader & reader) throw(emString);
+	virtual void TryStartReading(emRecReader & reader);
+	virtual bool TryContinueReading(emRecReader & reader);
 	virtual void QuitReading();
-	virtual void TryStartWriting(emRecWriter & writer) throw(emString);
-	virtual bool TryContinueWriting(emRecWriter & writer) throw(emString);
+	virtual void TryStartWriting(emRecWriter & writer);
+	virtual bool TryContinueWriting(emRecWriter & writer);
 	virtual void QuitWriting();
 	virtual emUInt64 CalcRecMemNeed() const;
 		// See emRec.
@@ -713,7 +716,7 @@ inline emFlagsRec & emFlagsRec::operator = (int value)
 	return *this;
 }
 
-inline int emFlagsRec::GetIdentifierCount()
+inline int emFlagsRec::GetIdentifierCount() const
 {
 	return IdentifierCount;
 }
@@ -753,11 +756,11 @@ public:
 
 	virtual void SetToDefault();
 	virtual bool IsSetToDefault() const;
-	virtual void TryStartReading(emRecReader & reader) throw(emString);
-	virtual bool TryContinueReading(emRecReader & reader) throw(emString);
+	virtual void TryStartReading(emRecReader & reader);
+	virtual bool TryContinueReading(emRecReader & reader);
 	virtual void QuitReading();
-	virtual void TryStartWriting(emRecWriter & writer) throw(emString);
-	virtual bool TryContinueWriting(emRecWriter & writer) throw(emString);
+	virtual void TryStartWriting(emRecWriter & writer);
+	virtual bool TryContinueWriting(emRecWriter & writer);
 	virtual void QuitWriting();
 	virtual emUInt64 CalcRecMemNeed() const;
 		// See emRec.
@@ -818,11 +821,11 @@ public:
 
 	virtual void SetToDefault();
 	virtual bool IsSetToDefault() const;
-	virtual void TryStartReading(emRecReader & reader) throw(emString);
-	virtual bool TryContinueReading(emRecReader & reader) throw(emString);
+	virtual void TryStartReading(emRecReader & reader);
+	virtual bool TryContinueReading(emRecReader & reader);
 	virtual void QuitReading();
-	virtual void TryStartWriting(emRecWriter & writer) throw(emString);
-	virtual bool TryContinueWriting(emRecWriter & writer) throw(emString);
+	virtual void TryStartWriting(emRecWriter & writer);
+	virtual bool TryContinueWriting(emRecWriter & writer);
 	virtual void QuitWriting();
 	virtual emUInt64 CalcRecMemNeed() const;
 		// See emRec.
@@ -883,11 +886,11 @@ public:
 
 	virtual void SetToDefault();
 	virtual bool IsSetToDefault() const;
-	virtual void TryStartReading(emRecReader & reader) throw(emString);
-	virtual bool TryContinueReading(emRecReader & reader) throw(emString);
+	virtual void TryStartReading(emRecReader & reader);
+	virtual bool TryContinueReading(emRecReader & reader);
 	virtual void QuitReading();
-	virtual void TryStartWriting(emRecWriter & writer) throw(emString);
-	virtual bool TryContinueWriting(emRecWriter & writer) throw(emString);
+	virtual void TryStartWriting(emRecWriter & writer);
+	virtual bool TryContinueWriting(emRecWriter & writer);
 	virtual void QuitWriting();
 	virtual emUInt64 CalcRecMemNeed() const;
 		// See emRec.
@@ -947,15 +950,15 @@ public:
 		// Get a reference to a member. The index must be within the
 		// range of 0 to GetCount()-1.
 
-	const char * GetIdentifierOf(int index);
+	const char * GetIdentifierOf(int index) const;
 		// Get the identifier for the given member index. Returns NULL
 		// if the index is out of range.
 
-	int GetIndexOf(emRec * member);
+	int GetIndexOf(const emRec * member) const;
 		// Get the member index for the given member pointer. Returns -1
 		// if there is no such member.
 
-	int GetIndexOf(const char * identifier);
+	int GetIndexOf(const char * identifier) const;
 		// Get the member index for the given identifier. Returns -1 if
 		// there is no such identifier.
 
@@ -966,11 +969,11 @@ public:
 
 	virtual void SetToDefault();
 	virtual bool IsSetToDefault() const;
-	virtual void TryStartReading(emRecReader & reader) throw(emString);
-	virtual bool TryContinueReading(emRecReader & reader) throw(emString);
+	virtual void TryStartReading(emRecReader & reader);
+	virtual bool TryContinueReading(emRecReader & reader);
 	virtual void QuitReading();
-	virtual void TryStartWriting(emRecWriter & writer) throw(emString);
-	virtual bool TryContinueWriting(emRecWriter & writer) throw(emString);
+	virtual void TryStartWriting(emRecWriter & writer);
+	virtual bool TryContinueWriting(emRecWriter & writer);
 	virtual void QuitWriting();
 	virtual emUInt64 CalcRecMemNeed() const;
 		// See emRec.
@@ -1073,21 +1076,21 @@ public:
 	int GetVariantCount() const;
 		// Get number of variants.
 
-	const char * GetIdentifierOf(int variant);
+	const char * GetIdentifierOf(int variant) const;
 		// Get the identifier for the given variant index. Returns NULL
 		// if there is no such variant.
 
-	int GetVariantOf(const char * identifier);
+	int GetVariantOf(const char * identifier) const;
 		// Get the variant index for the given identifier. Returns -1 if
 		// there is no such identifier.
 
 	virtual void SetToDefault();
 	virtual bool IsSetToDefault() const;
-	virtual void TryStartReading(emRecReader & reader) throw(emString);
-	virtual bool TryContinueReading(emRecReader & reader) throw(emString);
+	virtual void TryStartReading(emRecReader & reader);
+	virtual bool TryContinueReading(emRecReader & reader);
 	virtual void QuitReading();
-	virtual void TryStartWriting(emRecWriter & writer) throw(emString);
-	virtual bool TryContinueWriting(emRecWriter & writer) throw(emString);
+	virtual void TryStartWriting(emRecWriter & writer);
+	virtual bool TryContinueWriting(emRecWriter & writer);
 	virtual void QuitWriting();
 	virtual emUInt64 CalcRecMemNeed() const;
 		// See emRec.
@@ -1186,11 +1189,11 @@ public:
 
 	virtual void SetToDefault();
 	virtual bool IsSetToDefault() const;
-	virtual void TryStartReading(emRecReader & reader) throw(emString);
-	virtual bool TryContinueReading(emRecReader & reader) throw(emString);
+	virtual void TryStartReading(emRecReader & reader);
+	virtual bool TryContinueReading(emRecReader & reader);
 	virtual void QuitReading();
-	virtual void TryStartWriting(emRecWriter & writer) throw(emString);
-	virtual bool TryContinueWriting(emRecWriter & writer) throw(emString);
+	virtual void TryStartWriting(emRecWriter & writer);
+	virtual bool TryContinueWriting(emRecWriter & writer);
 	virtual void QuitWriting();
 	virtual emUInt64 CalcRecMemNeed() const;
 		// See emRec.
@@ -1261,7 +1264,7 @@ public:
 	REC & Get(int index);
 	const REC & operator [] (int index) const;
 	REC & operator [] (int index);
-		// Like with emArrayRec, but the results are casted...
+		// Like with emArrayRec, but the results are cast to template type.
 };
 
 template <class REC> inline emTArrayRec<REC>::emTArrayRec(
@@ -1316,16 +1319,16 @@ public:
 	emRecReader();
 	virtual ~emRecReader();
 
-	void TryStartReading(emRec & root) throw(emString);
+	void TryStartReading(emRec & root);
 		// Start reading.
 		// Arguments:
 		//   root - The root of the records to filled.
 
-	bool TryContinueReading() throw(emString);
+	bool TryContinueReading();
 		// Continue reading. Returns true when ready, otherwise
 		// TryContinueReading has to be called again.
 
-	void TryFinishReading() throw(emString);
+	void TryFinishReading();
 		// Continue reading until ready.
 
 	void QuitReading();
@@ -1342,43 +1345,43 @@ public:
 		ET_END
 	};
 
-	ElementType TryPeekNext(char * pDelimiter=NULL) throw(emString);
+	ElementType TryPeekNext(char * pDelimiter=NULL);
 		// Peek for the type of the next syntactical element to be read.
 		// If it is ET_DELIMITER and if pDelimiter is not NULL,
-		// *pDelimiter is set to the delimiter character,
+		// *pDelimiter is set to the delimiter character.
 
-	char TryReadDelimiter() throw(emString);
+	char TryReadDelimiter();
 		// Read the next syntactical element as a delimiter or throw an
 		// error. Currently, a delimiter can be any character except for
 		// white space, letters, digits, '#', '_' and '"'. The
 		// characters '.', '-' and '+' can be delimiters only if not
 		// confusable with numbers.
 
-	void TryReadCertainDelimiter(char delimiter) throw(emString);
+	void TryReadCertainDelimiter(char delimiter);
 		// Read the next syntactical element as the given delimiter or
 		// throw an error.
 
-	const char * TryReadIdentifier() throw(emString);
+	const char * TryReadIdentifier();
 		// Read the next syntactical element as an identifier or throw
 		// an error.
 
-	int TryReadInt() throw(emString);
+	int TryReadInt();
 		// Read the next syntactical element as an integer value or
 		// throw an error.
 
-	double TryReadDouble() throw(emString);
+	double TryReadDouble();
 		// Read the next syntactical element as a double value or throw
 		// an error.
 
-	const char * TryReadQuoted() throw(emString);
+	const char * TryReadQuoted();
 		// Read and unquote the next syntactical element as a quoted
 		// string or throw an error.
 
-	void ThrowElemError(const char * text) const throw(emString);
+	void ThrowElemError(const char * text) const;
 		// Throw an error containing the file name, the current line
 		// number and the given text.
 
-	void ThrowSyntaxError() const throw(emString);
+	void ThrowSyntaxError() const;
 		// Like ThrowElemError("syntax error")
 
 	const emRec * GetRootRec() const;
@@ -1386,12 +1389,12 @@ public:
 
 protected:
 
-	virtual int TryRead(char * buf, int maxLen) throw(emString) = 0;
+	virtual int TryRead(char * buf, int maxLen) = 0;
 		// Read up to maxLen bytes from the source into the given
 		// buffer, or throw an error. Return the number of bytes read,
 		// or 0 if the end of source has been reached.
 
-	virtual void TryClose() throw(emString) = 0;
+	virtual void TryClose() = 0;
 		// Close the source, or throw an error.
 
 	virtual const char * GetSourceName() const = 0;
@@ -1401,8 +1404,8 @@ protected:
 private:
 
 	void SetMinNextBufSize(int minSize);
-	void TryNextChar() throw(emString);
-	void TryParseNext() throw(emString);
+	void TryNextChar();
+	void TryParseNext();
 
 	emRec * Root;
 	bool RootQuitPending;
@@ -1438,16 +1441,16 @@ public:
 	emRecWriter();
 	virtual ~emRecWriter();
 
-	void TryStartWriting(emRec & root) throw(emString);
+	void TryStartWriting(emRec & root);
 		// Start writing.
 		// Arguments:
 		//   root - The root of the records to be written.
 
-	bool TryContinueWriting() throw(emString);
+	bool TryContinueWriting();
 		// Continue writing. Returns true when ready, otherwise
 		// TryContinueWriting has to be called again.
 
-	void TryFinishWriting() throw(emString);
+	void TryFinishWriting();
 		// Continue writing until ready.
 
 	void QuitWriting();
@@ -1455,28 +1458,28 @@ public:
 
 	// - - The following things are for implementing emRec derivatives - -
 
-	void TryWriteDelimiter(char c) throw(emString);
+	void TryWriteDelimiter(char c);
 		// Write the given delimiter character.
 
-	void TryWriteIdentifier(const char * idf) throw(emString);
+	void TryWriteIdentifier(const char * idf);
 		// Write the given identifier.
 
-	void TryWriteInt(int i) throw(emString);
+	void TryWriteInt(int i);
 		// Write the given integer value.
 
-	void TryWriteDouble(double d) throw(emString);
+	void TryWriteDouble(double d);
 		// Write the given double value.
 
-	void TryWriteQuoted(const char * q) throw(emString);
+	void TryWriteQuoted(const char * q);
 		// Quote and write the given string.
 
-	void TryWriteSpace() throw(emString);
+	void TryWriteSpace();
 		// Write a space character.
 
-	void TryWriteNewLine() throw(emString);
+	void TryWriteNewLine();
 		// Write a new-line character.
 
-	void TryWriteIndent() throw(emString);
+	void TryWriteIndent();
 		// Write an indent (to be called only at beginning of a new
 		// line). It is a number of tabulator characters.
 
@@ -1490,11 +1493,11 @@ public:
 
 protected:
 
-	virtual void TryWrite(const char * buf, int len) throw(emString) = 0;
+	virtual void TryWrite(const char * buf, int len) = 0;
 		// Write len bytes from the given buffer to the target, or throw
 		// an error.
 
-	virtual void TryClose() throw(emString) = 0;
+	virtual void TryClose() = 0;
 		// Flush and close the target, or throw an error.
 
 private:
@@ -1538,7 +1541,7 @@ public:
 	virtual ~emRecFileReader();
 
 	void TryStartReading(emRec & root,
-	                     const emString & filePath) throw(emString);
+	                     const emString & filePath);
 		// Start reading.
 		// Arguments:
 		//   root     - The root of the tree of records to be read from
@@ -1556,8 +1559,8 @@ public:
 
 protected:
 
-	virtual int TryRead(char * buf, int maxLen) throw(emString);
-	virtual void TryClose() throw(emString);
+	virtual int TryRead(char * buf, int maxLen);
+	virtual void TryClose();
 	virtual const char * GetSourceName() const;
 
 private:
@@ -1591,8 +1594,7 @@ public:
 	emRecFileWriter();
 	virtual ~emRecFileWriter();
 
-	void TryStartWriting(emRec & root,
-	                     const emString & filePath) throw(emString);
+	void TryStartWriting(emRec & root, const emString & filePath);
 		// Start writing.
 		// Arguments:
 		//   root     - The root of the tree of records to be written to
@@ -1601,8 +1603,8 @@ public:
 
 protected:
 
-	virtual void TryWrite(const char * buf, int len) throw(emString);
-	virtual void TryClose() throw(emString);
+	virtual void TryWrite(const char * buf, int len);
+	virtual void TryClose();
 
 private:
 
@@ -1624,7 +1626,7 @@ public:
 	emRecMemReader();
 
 	void TryStartReading(emRec & root, const char * buf,
-	                     int len) throw(emString);
+	                     int len);
 		// Start reading.
 		// Arguments:
 		//   root  - The root of the tree of records to be read from
@@ -1635,8 +1637,8 @@ public:
 
 protected:
 
-	virtual int TryRead(char * buf, int maxLen) throw(emString);
-	virtual void TryClose() throw(emString);
+	virtual int TryRead(char * buf, int maxLen);
+	virtual void TryClose();
 	virtual const char * GetSourceName() const;
 
 private:
@@ -1658,8 +1660,7 @@ public:
 	emRecMemWriter();
 	virtual ~emRecMemWriter();
 
-	void TryStartWriting(emRec & root,
-	                     emArray<char> & buf) throw(emString);
+	void TryStartWriting(emRec & root, emArray<char> & buf);
 		// Start writing. This and the other Try methods should never
 		// fail.
 		// Arguments:
@@ -1671,8 +1672,8 @@ public:
 
 protected:
 
-	virtual void TryWrite(const char * buf, int len) throw(emString);
-	virtual void TryClose() throw(emString);
+	virtual void TryWrite(const char * buf, int len);
+	virtual void TryClose();
 
 private:
 
