@@ -4,7 +4,7 @@ use strict;
 use warnings;
 use Config;
 
-sub GetDepedencies
+sub GetDependencies
 {
 	return ();
 }
@@ -22,9 +22,9 @@ sub GetFileHandlingRules
 		'-clean-install-exec-private-nobackup:.*',
 
 		# Set the exec flag for all files ending with '.sh', '.pl',
-		# '.exe' or '.dll' (It's Cygwin which needs exec flags on
-		# DLLs).
-		'+exec:\.(sh|pl|exe|dll)$',
+		# '.py', '.exe' or '.dll' (It's Cygwin which needs exec flags
+		# on DLLs).
+		'+exec:\.(sh|pl|py|exe|dll)$',
 
 		# Set the exec flag for the 'bin' directory tree.
 		'+exec:^bin(/|$)',
@@ -42,8 +42,9 @@ sub GetFileHandlingRules
 		# but res/xxx/src.old/yyy would!)
 		'-clean-install:(^|/)src(/|$)',
 
-		# And do not install the postscript documentation on Windows.
-		$Config{'osname'} eq "MSWin32" ? ('-install:^doc/ps(/|$)') : ()
+		# Beyond that, do not back up, release, or install any path
+		# where a name ends with '.tmp'.
+		'+nobackup+private-install:\.tmp(/|$)',
 
 	);
 }
