@@ -16,7 +16,7 @@ sub IsEssential
 
 sub GetFileHandlingRules
 {
-	return ('+exec:^lib/emAv/emAvServerProc_xine$');
+	return ('+exec:^lib/emAv/emAvServerProc_(vlc|xine)$');
 }
 
 sub GetExtraBuildOptions
@@ -24,9 +24,9 @@ sub GetExtraBuildOptions
 	return (
 		[
 			"emAv",
-			$Config{'osname'} eq "MSWin32" ? "vlc" : "xine",
+			"vlc",
 			"emAv=<name>[,<name>]...\n".
-			"  Which emAv server adapters to compile. Possible names are: xine, vlc"
+			"  Which emAv server adapters to compile. Possible names are: vlc, xine"
 		],
 		[
 			"xine-inc-dir",
@@ -58,6 +58,10 @@ sub Build
 		"--obj-dir"       , "obj",
 		"--inc-search-dir", "include",
 		"--link"          , "emCore",
+		$Config{'osname'} eq 'MSWin32' ? (
+			"--link"        , "user32",
+			"--link"        , "advapi32"
+		):(),
 		"--type"          , "dynlib",
 		"--name"          , "emAv",
 		"src/emAv/emAvClient.cpp",
@@ -65,6 +69,9 @@ sub Build
 		"src/emAv/emAvFileModel.cpp",
 		"src/emAv/emAvFilePanel.cpp",
 		"src/emAv/emAvFpPlugin.cpp",
+		"src/emAv/emAvImageConverter.cpp",
+		"src/emAv/emAvImageConverter_AVX2.cpp",
+		"src/emAv/emAvLibDirCfg.cpp",
 		"src/emAv/emAvServerModel.cpp",
 		"src/emAv/emAvStates.cpp"
 	)==0 or return 0;
@@ -75,43 +82,12 @@ sub Build
 	)==0 or return 0;
 
 	foreach my $name (split(',', $options{'emAv'})) {
-		if ($name eq 'xine') {
-			system(
-				@{$options{'unicc_call'}},
-				"--math",
-				"--rtti",
-				"--exceptions",
-				"--bin-dir"       , "lib/emAv",
-				"--lib-dir"       , "lib",
-				"--obj-dir"       , "obj",
-				"--inc-search-dir", "include",
-				$options{'xine-inc-dir'} ne '' ? (
-					"--inc-search-dir", $options{'xine-inc-dir'}
-				) : (),
-				$options{'xine-lib-dir'} ne '' ? (
-					"--lib-search-dir", $options{'xine-lib-dir'}
-				) : (),
-				"--link"          , "xine",
-				"--link"          , "pthread",
-				"--type"          , "cexe",
-				"--name"          , "emAvServerProc_xine",
-				"src/emAv/emAvServerProc_xine.c"
-			)==0 or return 0;
-		}
-		elsif ($name eq 'vlc') {
-			my @libvlcFlags=();
-			my $str=readpipe('pkg-config --cflags --libs libvlc');
-			if (!$str) { return 0; }
-			foreach my $f (split(/\s+/,$str)) {
-				if (substr($f,0,2) eq '-I') {
-					push(@libvlcFlags,'--inc-search-dir',substr($f,2));
-				}
-				elsif (substr($f,0,2) eq '-L') {
-					push(@libvlcFlags,'--lib-search-dir',substr($f,2));
-				}
-				elsif (substr($f,0,2) eq '-l') {
-					push(@libvlcFlags,'--link',substr($f,2));
-				}
+		if ($name eq 'vlc') {
+			my @libvlcFlags=split("\n",readpipe(
+				"perl \"".$options{'utils'}."/PkgConfig.pl\" libvlc"
+			));
+			if (!@libvlcFlags) {
+				@libvlcFlags=("--link","vlc");
 			}
 			system(
 				@{$options{'unicc_call'}},
@@ -123,11 +99,44 @@ sub Build
 				"--obj-dir"       , "obj",
 				"--inc-search-dir", "include",
 				@libvlcFlags,
+				"--link"          , "pthread",
 				"--type"          , "cexe",
 				"--name"          , "emAvServerProc_vlc",
 				"src/emAv/emAvServerProc_vlc.c"
 			)==0 or return 0;
 		}
+		elsif ($name eq 'xine') {
+			my @libXineFlags=();
+			if ($options{'xine-inc-dir'} eq '' && $options{'xine-lib-dir'} eq '') {
+				@libXineFlags=split("\n",readpipe(
+					"perl \"".$options{'utils'}."/PkgConfig.pl\" libxine"
+				));
+			}
+			if (!@libXineFlags) {
+				if ($options{'xine-inc-dir'} ne '') {
+					push(@libXineFlags, "--inc-search-dir", $options{'xine-inc-dir'});
+				}
+				if ($options{'xine-lib-dir'} ne '') {
+					push(@libXineFlags, "--lib-search-dir", $options{'xine-lib-dir'});
+				}
+				push(@libXineFlags, "--link", "xine");
+			}
+			system(
+				@{$options{'unicc_call'}},
+				"--math",
+				"--rtti",
+				"--exceptions",
+				"--bin-dir"       , "lib/emAv",
+				"--lib-dir"       , "lib",
+				"--obj-dir"       , "obj",
+				"--inc-search-dir", "include",
+				@libXineFlags,
+				"--link"          , "pthread",
+				"--type"          , "cexe",
+				"--name"          , "emAvServerProc_xine",
+				"src/emAv/emAvServerProc_xine.c"
+			)==0 or return 0;
+		}
 		else {
 			print(STDERR "Unkown value for emAv option: $name\n");
 			return 0;
