@@ -99,6 +99,14 @@ sub Build
 		"src/emCore/emPackGroup.cpp",
 		"src/emCore/emPackLayout.cpp",
 		"src/emCore/emPainter.cpp",
+		"src/emCore/emPainter_ScTl.cpp",
+		"src/emCore/emPainter_ScTlIntGra.cpp",
+		"src/emCore/emPainter_ScTlIntImg.cpp",
+		"src/emCore/emPainter_ScTlIntImg_AVX2.cpp",
+		"src/emCore/emPainter_ScTlPSCol.cpp",
+		"src/emCore/emPainter_ScTlPSCol_AVX2.cpp",
+		"src/emCore/emPainter_ScTlPSInt.cpp",
+		"src/emCore/emPainter_ScTlPSInt_AVX2.cpp",
 		"src/emCore/emPanel.cpp",
 		"src/emCore/emPriSchedAgent.cpp",
 		"src/emCore/emProcess.cpp",
