@@ -2,6 +2,7 @@ package emPdf;
 
 use strict;
 use warnings;
+use Config;
 
 sub GetDependencies
 {
@@ -52,19 +53,11 @@ sub Build
 		"lib/emPdf"
 	)==0 or return 0;
 
-	my @libpopplerglibFlags=();
-	my $str=readpipe('pkg-config --cflags --libs gtk+-2.0 poppler-glib');
-	if (!$str) { return 0; }
-	foreach my $f (split(/\s+/,$str)) {
-		if (substr($f,0,2) eq '-I') {
-			push(@libpopplerglibFlags,'--inc-search-dir',substr($f,2));
-		}
-		elsif (substr($f,0,2) eq '-L') {
-			push(@libpopplerglibFlags,'--lib-search-dir',substr($f,2));
-		}
-		elsif (substr($f,0,2) eq '-l') {
-			push(@libpopplerglibFlags,'--link',substr($f,2));
-		}
+	my @libpopplerglibFlags=split("\n",readpipe(
+		"perl \"".$options{'utils'}."/PkgConfig.pl\" gtk+-2.0 poppler-glib"
+	));
+	if (!@libpopplerglibFlags) {
+		@libpopplerglibFlags=("--link","poppler-glib");
 	}
 
 	system(
@@ -77,6 +70,7 @@ sub Build
 		"--obj-dir"       , "obj",
 		"--inc-search-dir", "include",
 		@libpopplerglibFlags,
+		$Config{'osname'} eq 'MSWin32' ? ("--link", "user32"):(),
 		"--type"          , "cexe",
 		"--name"          , "emPdfServerProc",
 		"src/emPdf/emPdfServerProc.c"
