@@ -1,7 +1,7 @@
 //------------------------------------------------------------------------------
 // emConfigModel.cpp
 //
-// Copyright (C) 2006-2008,2011,2014,2018 Oliver Hamann.
+// Copyright (C) 2006-2008,2011,2014,2018-2020 Oliver Hamann.
 //
 // Homepage: http://eaglemode.sourceforge.net/
 //
@@ -38,8 +38,8 @@ void emConfigModel::Save(bool force)
 	try {
 		TrySave(force);
 	}
-	catch (emException & exception) {
-		emFatalError("%s",exception.GetText());
+	catch (const emException & exception) {
+		emFatalError("%s",exception.GetText().Get());
 	}
 }
 
@@ -89,8 +89,8 @@ void emConfigModel::Load()
 	try {
 		TryLoad();
 	}
-	catch (emException & exception) {
-		emFatalError("%s",exception.GetText());
+	catch (const emException & exception) {
+		emFatalError("%s",exception.GetText().Get());
 	}
 }
 
@@ -119,8 +119,8 @@ void emConfigModel::LoadOrInstall(const char * insSrcPath)
 	try {
 		TryLoadOrInstall(insSrcPath);
 	}
-	catch (emException & exception) {
-		emFatalError("%s",exception.GetText());
+	catch (const emException & exception) {
+		emFatalError("%s",exception.GetText().Get());
 	}
 }
 
