@@ -1,7 +1,7 @@
 //------------------------------------------------------------------------------
 // emProcess.cpp
 //
-// Copyright (C) 2006-2009 Oliver Hamann.
+// Copyright (C) 2006-2009,2012,2014,2017-2018 Oliver Hamann.
 //
 // Homepage: http://eaglemode.sourceforge.net/
 //
@@ -85,7 +85,7 @@ emProcess::~emProcess()
 void emProcess::TryStart(
 	const emArray<emString> & args, const emArray<emString> & extraEnv,
 	const char * dirPath, int flags
-) throw(emString)
+)
 {
 	PROCESS_INFORMATION pi;
 	STARTUPINFO si;
@@ -151,7 +151,7 @@ void emProcess::TryStart(
 		str=extraEnv[i];
 		p=strchr(str.Get(),'=');
 		if (p) k=p-str.Get();
-		else k=strlen(p);
+		else k=str.GetLen();
 		for (j=0; j<env.GetCount(); j++) {
 			if (
 				env[j].GetLen()>=k &&
@@ -214,7 +214,7 @@ void emProcess::TryStart(
 			NULL,
 			NULL,
 			TRUE,
-			0,
+			(flags&SF_NO_WINDOW) ? CREATE_NO_WINDOW : 0,
 			(LPVOID)envBlock.Get(),
 			useDir.Get(),
 			&si,
@@ -226,7 +226,7 @@ void emProcess::TryStart(
 		CloseWriting();
 		CloseReading();
 		CloseReadingErr();
-		throw emString::Format(
+		throw emException(
 			"Failed to start process \"%s\": %s",
 			args[0].Get(),
 			emGetErrorText(d).Get()
@@ -246,7 +246,7 @@ void emProcess::TryStart(
 void emProcess::TryStartUnmanaged(
 	const emArray<emString> & args, const emArray<emString> & extraEnv,
 	const char * dirPath, int flags
-) throw(emString)
+)
 {
 	emProcess p;
 
@@ -264,7 +264,7 @@ void emProcess::TryStartUnmanaged(
 }
 
 
-int emProcess::TryWrite(const char * buf, int len) throw(emString)
+int emProcess::TryWrite(const char * buf, int len)
 {
 	emProcessPrivate::PipeStruct * pipe;
 	int done,l;
@@ -288,7 +288,7 @@ int emProcess::TryWrite(const char * buf, int len) throw(emString)
 	if (s==0 || s==ERROR_IO_PENDING || s==ERROR_IO_INCOMPLETE) return 0;
 	CloseWriting();
 	if (s==ERROR_HANDLE_EOF || s==ERROR_BROKEN_PIPE) return -1;
-	throw emString::Format(
+	throw emException(
 		"Failed to write to stdin pipe of child process \"%s\": %s",
 		P->Arg0.Get(),
 		emGetErrorText(s).Get()
@@ -296,7 +296,7 @@ int emProcess::TryWrite(const char * buf, int len) throw(emString)
 }
 
 
-int emProcess::TryRead(char * buf, int maxLen) throw(emString)
+int emProcess::TryRead(char * buf, int maxLen)
 {
 	emProcessPrivate::PipeStruct * pipe;
 	int done,l;
@@ -320,7 +320,7 @@ int emProcess::TryRead(char * buf, int maxLen) throw(emString)
 	if (s==0 || s==ERROR_IO_PENDING || s==ERROR_IO_INCOMPLETE) return 0;
 	CloseReading();
 	if (s==ERROR_HANDLE_EOF || s==ERROR_BROKEN_PIPE) return -1;
-	throw emString::Format(
+	throw emException(
 		"Failed to read stdout pipe of child process \"%s\": %s",
 		P->Arg0.Get(),
 		emGetErrorText(s).Get()
@@ -328,7 +328,7 @@ int emProcess::TryRead(char * buf, int maxLen) throw(emString)
 }
 
 
-int emProcess::TryReadErr(char * buf, int maxLen) throw(emString)
+int emProcess::TryReadErr(char * buf, int maxLen)
 {
 	emProcessPrivate::PipeStruct * pipe;
 	int done,l;
@@ -352,7 +352,7 @@ int emProcess::TryReadErr(char * buf, int maxLen) throw(emString)
 	if (s==0 || s==ERROR_IO_PENDING || s==ERROR_IO_INCOMPLETE) return 0;
 	CloseReadingErr();
 	if (s==ERROR_HANDLE_EOF || s==ERROR_BROKEN_PIPE) return -1;
-	throw emString::Format(
+	throw emException(
 		"Failed to read stderr pipe of child process \"%s\": %s",
 		P->Arg0.Get(),
 		emGetErrorText(s).Get()
@@ -386,7 +386,7 @@ void emProcess::WaitPipes(int waitFlags, unsigned timeoutMS)
 		timeoutMS==UINT_MAX ? INFINITE : (DWORD)timeoutMS
 	)==WAIT_FAILED) {
 		emFatalError(
-			"emProcess: WaitForMultipleObjects failed: %s\n",
+			"emProcess: WaitForMultipleObjects failed: %s",
 			emGetErrorText(GetLastError()).Get()
 		);
 	}
@@ -519,7 +519,7 @@ HANDLE emProcessPrivate::PreparePipe(int index)
 		if (h1!=INVALID_HANDLE_VALUE) break;
 		if (i>1000) {
 			emFatalError(
-				"emProcess: CreateNamedPipe failed: %s\n",
+				"emProcess: CreateNamedPipe failed: %s",
 				emGetErrorText(GetLastError()).Get()
 			);
 		}
@@ -541,7 +541,7 @@ HANDLE emProcessPrivate::PreparePipe(int index)
 	);
 	if (h2==INVALID_HANDLE_VALUE) {
 		emFatalError(
-			"emProcess: CreateFile on named pipe failed: %s\n",
+			"emProcess: CreateFile on named pipe failed: %s",
 			emGetErrorText(GetLastError()).Get()
 		);
 	}
@@ -663,7 +663,6 @@ void emProcessPrivate::ClosePipe(int index)
 //====================== UNIX implementation of emProcess ======================
 //==============================================================================
 
-#include <emCore/emThread.h>
 #include <signal.h>
 #include <sys/wait.h>
 #include <sys/time.h>
@@ -681,7 +680,7 @@ struct emProcessPrivate {
 		const char * dirPath,
 		int flags,
 		emProcessPrivate * managed
-	) throw(emString);
+	);
 
 	emString Arg0;
 	pid_t Pid;
@@ -713,7 +712,7 @@ emProcess::~emProcess()
 void emProcess::TryStart(
 	const emArray<emString> & args, const emArray<emString> & extraEnv,
 	const char * dirPath, int flags
-) throw(emString)
+)
 {
 	emProcessPrivate::TryStart(args,extraEnv,dirPath,flags,P);
 }
@@ -722,14 +721,14 @@ void emProcess::TryStart(
 void emProcess::TryStartUnmanaged(
 	const emArray<emString> & args, const emArray<emString> & extraEnv,
 	const char * dirPath, int flags
-) throw(emString)
+)
 {
 	flags&=~(SF_PIPE_STDIN|SF_PIPE_STDOUT|SF_PIPE_STDERR);
 	emProcessPrivate::TryStart(args,extraEnv,dirPath,flags,NULL);
 }
 
 
-int emProcess::TryWrite(const char * buf, int len) throw(emString)
+int emProcess::TryWrite(const char * buf, int len)
 {
 	ssize_t r;
 	int e;
@@ -745,7 +744,7 @@ int emProcess::TryWrite(const char * buf, int len) throw(emString)
 	}
 	e=errno;
 	CloseWriting();
-	throw emString::Format(
+	throw emException(
 		"Failed to write to stdin pipe of child process \"%s\" (pid %d): %s",
 		P->Arg0.Get(),
 		(int)P->Pid,
@@ -754,7 +753,7 @@ int emProcess::TryWrite(const char * buf, int len) throw(emString)
 }
 
 
-int emProcess::TryRead(char * buf, int maxLen) throw(emString)
+int emProcess::TryRead(char * buf, int maxLen)
 {
 	ssize_t r;
 	int e;
@@ -770,7 +769,7 @@ int emProcess::TryRead(char * buf, int maxLen) throw(emString)
 	if (errno==EAGAIN) return 0;
 	e=errno;
 	CloseReading();
-	throw emString::Format(
+	throw emException(
 		"Failed to read stdout pipe of child process \"%s\" (pid %d): %s",
 		P->Arg0.Get(),
 		(int)P->Pid,
@@ -779,7 +778,7 @@ int emProcess::TryRead(char * buf, int maxLen) throw(emString)
 }
 
 
-int emProcess::TryReadErr(char * buf, int maxLen) throw(emString)
+int emProcess::TryReadErr(char * buf, int maxLen)
 {
 	ssize_t r;
 	int e;
@@ -795,7 +794,7 @@ int emProcess::TryReadErr(char * buf, int maxLen) throw(emString)
 	if (errno==EAGAIN) return 0;
 	e=errno;
 	CloseReadingErr();
-	throw emString::Format(
+	throw emException(
 		"Failed to read stderr pipe of child process \"%s\" (pid %d): %s",
 		P->Arg0.Get(),
 		(int)P->Pid,
@@ -840,7 +839,7 @@ void emProcess::WaitPipes(int waitFlags, unsigned timeoutMS)
 	if (select(fdMax+1,&rset,&wset,NULL,ptv)<0) {
 		if (errno!=EINTR) {
 			emFatalError(
-				"emProcess: select failed: %s\n",
+				"emProcess: select failed: %s",
 				emGetErrorText(errno).Get()
 			);
 		}
@@ -958,10 +957,8 @@ void emProcessPrivate::EmptySigHandler(int signum)
 void emProcessPrivate::TryStart(
 	const emArray<emString> & args, const emArray<emString> & extraEnv,
 	const char * dirPath, int flags, emProcessPrivate * managed
-) throw(emString)
+)
 {
-	static emThreadInitMutex sigHandlersInitMutex;
-	struct sigaction sa;
 	char buf[1024];
 	emString msg;
 	int pipeIn[2],pipeOut[2],pipeErr[2],pipeTmp[2];
@@ -994,27 +991,29 @@ void emProcessPrivate::TryStart(
 		flags&=~emProcess::SF_SHARE_STDERR;
 	}
 
-	if (sigHandlersInitMutex.Begin()) {
-		memset(&sa,0,sizeof(sa));
-		sa.sa_handler=EmptySigHandler;
-		sa.sa_flags=SA_RESTART;
-		if (sigaction(SIGCHLD,&sa,NULL)) {
-			emFatalError(
-				"emProcess: Failed to install handler for SIGCHLD: %s",
-				emGetErrorText(errno).Get()
-			);
+	static const struct SigHandlersInstaller {
+		SigHandlersInstaller() {
+			struct sigaction sa;
+			memset(&sa,0,sizeof(sa));
+			sa.sa_handler=EmptySigHandler;
+			sa.sa_flags=SA_RESTART;
+			if (sigaction(SIGCHLD,&sa,NULL)) {
+				emFatalError(
+					"emProcess: Failed to install handler for SIGCHLD: %s",
+					emGetErrorText(errno).Get()
+				);
+			}
+			memset(&sa,0,sizeof(sa));
+			sa.sa_handler=EmptySigHandler;
+			sa.sa_flags=SA_RESTART;
+			if (sigaction(SIGPIPE,&sa,NULL)) {
+				emFatalError(
+					"emProcess: Failed to install handler for SIGPIPE: %s",
+					emGetErrorText(errno).Get()
+				);
+			}
 		}
-		memset(&sa,0,sizeof(sa));
-		sa.sa_handler=EmptySigHandler;
-		sa.sa_flags=SA_RESTART;
-		if (sigaction(SIGPIPE,&sa,NULL)) {
-			emFatalError(
-				"emProcess: Failed to install handler for SIGPIPE: %s",
-				emGetErrorText(errno).Get()
-			);
-		}
-		sigHandlersInitMutex.End();
-	}
+	} sigHandlersInstaller;
 
 	pid=-1;
 	pipeIn[0]=-1;
@@ -1251,7 +1250,7 @@ L_Err:
 	if (pipeErr[1]!=-1) close(pipeErr[1]);
 	if (pipeTmp[0]!=-1) close(pipeTmp[0]);
 	if (pipeTmp[1]!=-1) close(pipeTmp[1]);
-	throw emString::Format(
+	throw emException(
 		"Failed to start process \"%s\": %s",
 		args[0].Get(),
 		msg.Get()
