@@ -1,7 +1,7 @@
 //------------------------------------------------------------------------------
 // emRes.cpp
 //
-// Copyright (C) 2006-2008,2014,2018 Oliver Hamann.
+// Copyright (C) 2006-2008,2014,2018-2020 Oliver Hamann.
 //
 // Homepage: http://eaglemode.sourceforge.net/
 //
@@ -33,8 +33,8 @@ emImage emGetResImage(
 	try {
 		return emTryGetResImage(rootContext,filePath,channelCount);
 	}
-	catch (emException & exception) {
-		emFatalError("%s",exception.GetText());
+	catch (const emException & exception) {
+		emFatalError("%s",exception.GetText().Get());
 		return emImage();
 	}
 }
@@ -64,11 +64,11 @@ emImage emTryGetResImage(
 				buf.GetCount()
 			);
 		}
-		catch (emException & exception) {
+		catch (const emException & exception) {
 			throw emException(
 				"Could not read image file \"%s\": %s",
 				absPath.Get(),
-				exception.GetText()
+				exception.GetText().Get()
 			);
 		}
 		buf.Clear();
