@@ -1,7 +1,7 @@
 //------------------------------------------------------------------------------
 // emMain.cpp
 //
-// Copyright (C) 2005-2011,2014-2018 Oliver Hamann.
+// Copyright (C) 2005-2011,2014-2021 Oliver Hamann.
 //
 // Homepage: http://eaglemode.sourceforge.net/
 //
@@ -49,7 +49,7 @@
 		_exit(128+sig);
 	}
 
-	static void __attribute((constructor)) InstallCrashHandler(void)
+	static void __attribute((constructor)) InstallCrashHandler()
 	{
 		signal(SIGFPE,CrashHandler);
 		signal(SIGSEGV,CrashHandler);
@@ -84,22 +84,15 @@ private:
 	void CreateFSDialog();
 	bool IsFSDialogDone();
 	void SetFSDialogDone();
-	emString GetLAPath();
+	static emString GetLAPath();
 
-	void CreateXWDialog();
-	bool IsXWDialogDone();
-	void SetXWDialogDone();
-
-	void CheckIfInstalledOverOldVersion();
+	static void CheckIfInstalledOverOldVersion();
 
 	emContext & Context;
 
 	bool FSDialogDone;
 	emDialog * FSDialog;
 
-	bool XWDialogDone;
-	emDialog * XWDialog;
-
 	emArray<emString> SavedArgs;
 };
 
@@ -114,8 +107,9 @@ emMain::emMain(emContext & context, bool serve)
 
 	FSDialogDone=false;
 	FSDialog=NULL;
-	XWDialogDone=false;
-	XWDialog=NULL;
+
+	CheckIfInstalledOverOldVersion();
+
 	if (serve) {
 		name=CalcServerName();
 		emDLog("emMain: MiniIPC server name is \"%s\".",name.Get());
@@ -167,8 +161,6 @@ void emMain::NewWindow(int argc, const char * const argv[])
 	emColor ceColor;
 	int i;
 
-	CheckIfInstalledOverOldVersion();
-
 	if (!IsFSDialogDone()) {
 		if (!FSDialog) {
 			SavedArgs.SetCount(argc,true);
@@ -178,15 +170,6 @@ void emMain::NewWindow(int argc, const char * const argv[])
 		return;
 	}
 
-	if (!IsXWDialogDone()) {
-		if (!XWDialog) {
-			SavedArgs.SetCount(argc,true);
-			for (i=0; i<argc; i++) SavedArgs.Set(i,emString(argv[i]));
-			CreateXWDialog();
-		}
-		return;
-	}
-
 	optGeometry=NULL;
 	optCEColor=NULL;
 	optMaximized=false;
@@ -231,10 +214,10 @@ void emMain::NewWindow(int argc, const char * const argv[])
 		try {
 			ceColor.TryParse(optCEColor);
 		}
-		catch (emException & exception) {
+		catch (const emException & exception) {
 			emWarning(
 				"emMain::NewWindow: Could not interpret cecolor option value: %s",
-				exception.GetText()
+				exception.GetText().Get()
 			);
 			ceColor=0;
 		}
@@ -292,21 +275,6 @@ bool emMain::Cycle()
 		}
 	}
 
-	if (XWDialog && IsSignaled(XWDialog->GetFinishSignal())) {
-		if (XWDialog->GetResult()==emDialog::POSITIVE) {
-			delete XWDialog;
-			XWDialog=NULL;
-			SetXWDialogDone();
-			args.SetCount(SavedArgs.GetCount(),true);
-			for (i=0; i<args.GetCount(); i++) args.Set(i,SavedArgs[i].Get());
-			NewWindow(args.GetCount(),args.Get());
-			SavedArgs.Clear(true);
-		}
-		else {
-			emEngine::GetScheduler().InitiateTermination(-1);
-		}
-	}
-
 	return false;
 }
 
@@ -388,7 +356,7 @@ bool emMain::IsFSDialogDone()
 	try {
 		buf=emTryLoadFile(GetLAPath());
 	}
-	catch (emException &) {
+	catch (const emException &) {
 		return false;
 	}
 	if (emString(buf.Get(),buf.GetCount())!="yes\n") {
@@ -406,8 +374,8 @@ void emMain::SetFSDialogDone()
 		emTryMakeDirectories(emGetParentPath(GetLAPath()));
 		emTrySaveFile(GetLAPath(),"yes\n",4);
 	}
-	catch (emException & exception) {
-		emFatalError("%s",exception.GetText());
+	catch (const emException & exception) {
+		emFatalError("%s",exception.GetText().Get());
 	}
 	FSDialogDone=true;
 }
@@ -419,62 +387,6 @@ emString emMain::GetLAPath()
 }
 
 
-void emMain::CreateXWDialog()
-{
-	static const char * const text=
-		"It seems you are running Eagle Mode on XWayland. This is\n"
-		"not recommended due to some incompatibilities or bugs!\n"
-		"(Among other flaws, often no keyboard input in popup\n"
-		"zoom, and mouse clicks sometimes go through to window\n"
-		"behind!)\n"
-		"\n"
-		"Please consider to run Eagle Mode on another type of X\n"
-		"server!\n"
-	;
-
-	if (XWDialog) return;
-
-	XWDialog=new emDialog(
-		Context,
-		emView::VF_ROOT_SAME_TALLNESS|emView::VF_NO_ZOOM,
-		emWindow::WF_MODAL,
-		"emXWaylandWarningDialog"
-	);
-	XWDialog->SetRootTitle("WARNING");
-	XWDialog->SetWindowIcon(
-		emGetInsResImage(Context.GetRootContext(),"icons","em-dialog48.tga")
-	);
-	XWDialog->AddPositiveButton("Continue");
-	XWDialog->AddNegativeButton("Abort");
-	new emLabel(XWDialog->GetContentPanel(),"text",text);
-	AddWakeUpSignal(XWDialog->GetFinishSignal());
-}
-
-
-bool emMain::IsXWDialogDone()
-{
-	if (XWDialogDone) return true;
-
-	bool(*func)(emContext&) = emVarModel<bool(*)(emContext&)>::Get(
-		Context,
-		"CheckIfUnreliableXWayland",
-		NULL
-	);
-	if (func && func(Context)) {
-		return false;
-	}
-
-	XWDialogDone=true;
-	return true;
-}
-
-
-void emMain::SetXWDialogDone()
-{
-	XWDialogDone=true;
-}
-
-
 void emMain::CheckIfInstalledOverOldVersion()
 {
 	static const struct {
@@ -505,7 +417,7 @@ void emMain::CheckIfInstalledOverOldVersion()
 		try {
 			file=emTryLoadFile(path);
 		}
-		catch (emException &) {
+		catch (const emException &) {
 			continue;
 		}
 		crc32=emCalcCRC32(file.Get(),file.GetCount());
@@ -634,7 +546,7 @@ static int wrapped_main(int argc, char * argv[])
 				sendArgs.Get()
 			);
 		}
-		catch (emException &) {
+		catch (const emException &) {
 			fprintf(stderr,"Failed to find server process.\n");
 			return 1;
 		}
@@ -657,7 +569,7 @@ static int wrapped_main(int argc, char * argv[])
 			);
 			return 0;
 		}
-		catch (emException &) {
+		catch (const emException &) {
 		}
 	}
 
