@@ -1,7 +1,7 @@
 //------------------------------------------------------------------------------
 // emPdfServerModel.cpp
 //
-// Copyright (C) 2011,2014,2017-2018 Oliver Hamann.
+// Copyright (C) 2011,2014,2017-2019 Oliver Hamann.
 //
 // Homepage: http://eaglemode.sourceforge.net/
 //
@@ -99,11 +99,30 @@ emPdfServerModel::PageInfo::PageInfo()
 }
 
 
+emPdfServerModel::PageInfo::PageInfo(const PageInfo & pageInfo)
+	: Width(pageInfo.Width),
+	Height(pageInfo.Height),
+	Label(pageInfo.Label)
+{
+}
+
+
 emPdfServerModel::PageInfo::~PageInfo()
 {
 }
 
 
+emPdfServerModel::PageInfo & emPdfServerModel::PageInfo::operator = (
+	const PageInfo & pageInfo
+)
+{
+	Width=pageInfo.Width;
+	Height=pageInfo.Height;
+	Label=pageInfo.Label;
+	return *this;
+}
+
+
 void emPdfServerModel::ClosePdf(PdfHandle pdfHandle)
 {
 	CloseJobStruct * job;
@@ -186,7 +205,7 @@ void emPdfServerModel::Poll(unsigned maxMilliSecs)
 			Process.WaitPipes(flags,(unsigned)(endTime-now));
 		}
 	}
-	catch (emException & exception) {
+	catch (const emException & exception) {
 		if (!FirstRunningJob) FailAllJobs(exception.GetText());
 		else FailAllRunningJobs(exception.GetText());
 		Process.SendTerminationSignal();
